package com.fastbee.rechargecard.service.impl;

import java.util.List;

import cn.hutool.core.lang.Console;
import com.fastbee.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.rechargecard.mapper.UserRechargeCardsMapper;
import com.fastbee.rechargecard.domain.UserRechargeCards;
import com.fastbee.rechargecard.service.IUserRechargeCardsService;

/**
 * 用户充值卡Service业务层处理
 *
 * @author kerwincui
 * @date 2024-12-17
 */
@Service
public class UserRechargeCardsServiceImpl implements IUserRechargeCardsService
{
    /*@Autowired
    private UserRechargeCardsMapper userRechargeCardsMapper;*/
    @Autowired
    private UserRechargeCardsMapper userRechargeCardsMapper;

    @Override
    public Long test(Long id) {
        return userRechargeCardsMapper.test(id);
    }

    /**
     * 查询用户充值卡
     *
     * @param id 用户充值卡主键
     * @return 用户充值卡
     */
    @Override
    public UserRechargeCards selectUserRechargeCardsById(Long id)
    {
        //return userRechargeCardsMapper.selectUserRechargeCardsById(id);
        //return id;
        System.out.println("selectUserRechargeCardsById");
        UserRechargeCards info=userRechargeCardsMapper.selectUserRechargeCardsById(id);
        return info;
    }

    /**
     * 查询用户充值卡列表
     *
     * @param userRechargeCards 用户充值卡
     * @return 用户充值卡
     */
    @Override
    public List<UserRechargeCards> selectUserRechargeCardsList(UserRechargeCards userRechargeCards)
    {
        return userRechargeCardsMapper.selectUserRechargeCardsList(userRechargeCards);
    }

    /**
     * 新增用户充值卡
     *
     * @param userRechargeCards 用户充值卡
     * @return 结果
     */
    @Override
    public int insertUserRechargeCards(UserRechargeCards userRechargeCards)
    {
        userRechargeCards.setCreateTime(DateUtils.getNowDate());
        return userRechargeCardsMapper.insertUserRechargeCards(userRechargeCards);
    }

    /**
     * 修改用户充值卡
     *
     * @param userRechargeCards 用户充值卡
     * @return 结果
     */
    @Override
    public int updateUserRechargeCards(UserRechargeCards userRechargeCards)
    {
        userRechargeCards.setUpdateTime(DateUtils.getNowDate());
        return userRechargeCardsMapper.updateUserRechargeCards(userRechargeCards);
    }

    /**
     * 批量删除用户充值卡
     *
     * @param ids 需要删除的用户充值卡主键
     * @return 结果
     */
    @Override
    public int deleteUserRechargeCardsByIds(Long[] ids)
    {
        return userRechargeCardsMapper.deleteUserRechargeCardsByIds(ids);
    }

    /**
     * 删除用户充值卡信息
     *
     * @param id 用户充值卡主键
     * @return 结果
     */
    @Override
    public int deleteUserRechargeCardsById(Long id)
    {
        return userRechargeCardsMapper.deleteUserRechargeCardsById(id);
    }
}
